@@ -29,20 +29,22 @@
 #include <eel/eel-canvas.h>
 #include <libnautilus-private/nautilus-icon-info.h>
 
+#define NAUTILUS_TYPE_ICON_CONTAINER nautilus_icon_container_get_type()
 #define NAUTILUS_ICON_CONTAINER(obj) \
-	GTK_CHECK_CAST (obj, nautilus_icon_container_get_type (), NautilusIconContainer)
-#define NAUTILUS_ICON_CONTAINER_CLASS(k) \
-	GTK_CHECK_CLASS_CAST (k, nautilus_icon_container_get_type (), NautilusIconContainerClass)
+  (G_TYPE_CHECK_INSTANCE_CAST ((obj), NAUTILUS_TYPE_ICON_CONTAINER, NautilusIconContainer))
+#define NAUTILUS_ICON_CONTAINER_CLASS(klass) \
+  (G_TYPE_CHECK_CLASS_CAST ((klass), NAUTILUS_TYPE_ICON_CONTAINER, NautilusIconContainerClass))
 #define NAUTILUS_IS_ICON_CONTAINER(obj) \
-	GTK_CHECK_TYPE (obj, nautilus_icon_container_get_type ())
+  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NAUTILUS_TYPE_ICON_CONTAINER))
+#define NAUTILUS_IS_ICON_CONTAINER_CLASS(klass) \
+  (G_TYPE_CHECK_CLASS_TYPE ((klass), NAUTILUS_TYPE_ICON_CONTAINER))
+#define NAUTILUS_ICON_CONTAINER_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_CLASS ((obj), NAUTILUS_TYPE_ICON_CONTAINER, NautilusIconContainerClass))
+
 
 #define NAUTILUS_ICON_CONTAINER_ICON_DATA(pointer) \
 	((NautilusIconData *) (pointer))
 
-#define NAUTILUS_ICON_CONTAINER_GET_CLASS(object) (G_TYPE_INSTANCE_GET_CLASS ((object), \
-					           nautilus_icon_container_get_type (), \
-						   NautilusIconContainerClass))
-
 typedef struct NautilusIconData NautilusIconData;
 
 typedef void (* NautilusIconCallback) (NautilusIconData *icon_data,
@@ -140,7 +142,8 @@ typedef struct {
 	void         (* get_icon_text)            (NautilusIconContainer *container,
 						   NautilusIconData *data,
 						   char **editable_text,
-						   char **additional_text);
+						   char **additional_text,
+						   gboolean include_invisible);
 	char *       (* get_icon_description)     (NautilusIconContainer *container,
 						   NautilusIconData *data);
 	int          (* compare_icons)            (NautilusIconContainer *container,
