@@ -448,7 +448,7 @@ nautilus_notes_viewer_create_sidebar (NautilusSidebarProvider *provider,
 	
 	sidebar = g_object_new (nautilus_notes_viewer_get_type (), NULL);
 	nautilus_notes_viewer_set_parent_window (sidebar, window);
-	g_object_ref (sidebar);
+	g_object_ref_sink (sidebar);
 
 	return NAUTILUS_SIDEBAR (sidebar);
 }
